<?php


namespace Tool\MayouTool;


use Curl\Curl;
use Tool\MayouTool\Exception\HttpCustomeException;

class HttpCurl
{
    /**
     * @var $curl Curl
     */
    static $curl;

    /**
     * @var int 超时时间
     */
    static $timeOut = 180;

    /**
     * @var int 连接超时时间
     */
    static $connectTimeOut = 5;

    /**
     * @param string $url 请求地址
     * @param array $params 请求参数
     * @param array $headers 请求头
     */
    public static function getCurl(string $url,array $params=[],array $headers=[],$ssl=false)
    {
        //判断是否存在traceId
        if(isset($_GET["traceId"])){
            $headers["traceId"] = $_GET["traceId"];
        }

        self::$curl = $curl = new Curl();
        //设置超时时间
        $curl->setOpt(CURLOPT_TIMEOUT,self::$timeOut);
        //设置连接超时时间
        $curl->setOpt(CURLOPT_CONNECTTIMEOUT,self::$connectTimeOut);

        //塞入header头
        foreach ($headers as $key=>$header){
            $curl->setHeader($key,$header);
        }
        if(!$ssl){
            $curl->setOpt(CURLOPT_SSL_VERIFYPEER,false);
            $curl->setOpt(CURLOPT_SSL_VERIFYHOST,false);
        }
        //塞入参数
        $curl->get($url,$params);
        return json_decode($curl->response,true);
    }


    /**
     * @param string $url 请求地址
     * @param array $params 请求参数
     * @param array $headers 请求头
     * @param bool $asJson 是否json传输(true是 false否)
     */
    public static function postCurl($url,$params=[],$headers=[],$asJson=true,$ssl=false)
    {
        //判断是否存在traceId
        if(isset($_GET["traceId"])){
            $headers["traceId"] = $_GET["traceId"];
        }

        self::$curl = $curl = new Curl();
        //设置超时时间
        $curl->setOpt(CURLOPT_TIMEOUT,self::$timeOut);
        //设置连接超时时间
        $curl->setOpt(CURLOPT_CONNECTTIMEOUT,self::$connectTimeOut);

        //塞入header头
        foreach ($headers as $key=>$header){
            $curl->setHeader($key,$header);
        }
        //判断是否json请求
        if($asJson){
            $curl->setHeader("Content-Type","application/json;charset=utf-8");
        }
        if(!$ssl){
            $curl->setOpt(CURLOPT_SSL_VERIFYPEER,false);
            $curl->setOpt(CURLOPT_SSL_VERIFYHOST,false);
        }
        //塞入参数
        $curl->post($url,$params,$asJson);
        return json_decode($curl->response,true);
    }

    /**
     * @param string $url 请求地址
     * @param array $params 请求参数
     * @param array $headers 请求头
     */
    public static function getCurlOrigin(string $url,array $params=[],array $headers=[],$ssl=false)
    {
        //判断是否存在traceId
        if(isset($_GET["traceId"])){
            $headers["traceId"] = $_GET["traceId"];
        }

        self::$curl = $curl = new Curl();
        //设置超时时间
        $curl->setOpt(CURLOPT_TIMEOUT,self::$timeOut);
        //设置连接超时时间
        $curl->setOpt(CURLOPT_CONNECTTIMEOUT,self::$connectTimeOut);

        //塞入header头
        foreach ($headers as $key=>$header){
            $curl->setHeader($key,$header);
        }
        if(!$ssl){
            $curl->setOpt(CURLOPT_SSL_VERIFYPEER,false);
            $curl->setOpt(CURLOPT_SSL_VERIFYHOST,false);
        }
        //塞入参数
        $curl->get($url,$params);
        return $curl->response;
    }


    /**
     * @param string $url 请求地址
     * @param array $params 请求参数
     * @param array $headers 请求头
     * @param bool $asJson 是否json传输(true是 false否)
     */
    public static function postCurlOrigin($url,$params=[],$headers=[],$asJson=true,$ssl=false)
    {
        //判断是否存在traceId
        if(isset($_GET["traceId"])){
            $headers["traceId"] = $_GET["traceId"];
        }

        self::$curl = $curl = new Curl();
        //设置超时时间
        $curl->setOpt(CURLOPT_TIMEOUT,self::$timeOut);
        //设置连接超时时间
        $curl->setOpt(CURLOPT_CONNECTTIMEOUT,self::$connectTimeOut);

        //塞入header头
        foreach ($headers as $key=>$header){
            $curl->setHeader($key,$header);
        }
        //判断是否json请求
        if($asJson){
            $curl->setHeader("Content-Type","application/json;charset=utf-8");
        }
        if(!$ssl){
            $curl->setOpt(CURLOPT_SSL_VERIFYPEER,false);
            $curl->setOpt(CURLOPT_SSL_VERIFYHOST,false);
        }
        //塞入参数
        $curl->post($url,$params,$asJson);
        return $curl->response;
    }

    /**
     * 后端转发上传文件
     * @param string $url
     * @param string $filepath
     */
    public static function uploadFile(string $url,string $filepath)
    {

        $file = new \CURLFile($filepath,"application/octet-stream");
        $data = [
            "media"=>$file
        ];
        $ch = curl_init($url);
        curl_setopt($ch,CURLOPT_POST,1);
        curl_setopt($ch,CURLOPT_POSTFIELDS,$data);
        curl_setopt($ch,CURLOPT_HTTPHEADER,["multipart/form-data"]);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch,CURLOPT_BINARYTRANSFER,true);
        $result = curl_exec($ch);
        if(curl_errno($ch)){
            curl_close($ch);
            throw new HttpCustomeException("文件上传失败");
        }
        curl_close($ch);
        $res = json_decode($result,1);
        if($res["errcode"]==0){
            return $res["media_id"];
        }
    }
}